aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/feed/factory.php
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/phpbb/feed/factory.php')
-rw-r--r--phpBB/phpbb/feed/factory.php11
1 files changed, 6 insertions, 5 deletions
diff --git a/phpBB/phpbb/feed/factory.php b/phpBB/phpbb/feed/factory.php
index 84b4d5d560..f364f06d03 100644
--- a/phpBB/phpbb/feed/factory.php
+++ b/phpBB/phpbb/feed/factory.php
@@ -13,6 +13,8 @@
namespace phpbb\feed;
+use Symfony\Component\DependencyInjection\ContainerInterface;
+
/**
* Factory class to return correct object
*/
@@ -20,7 +22,7 @@ class factory
{
/**
* Service container object
- * @var object
+ * @var ContainerInterface
*/
protected $container;
@@ -33,12 +35,11 @@ class factory
/**
* Constructor
*
* @param objec $container Container object
* @param \phpbb\config\config $config Config object
* @param \phpbb\db\driver\driver_interface $db Database connection
- * @return null
*/
- public function __construct($container, \phpbb\config\config $config, \phpbb\db\driver\driver_interface $db)
+ public function __construct(ContainerInterface $container, \phpbb\config\config $config, \phpbb\db\driver\driver_interface $db)
{
$this->container = $container;
$this->config = $config;
@@ -33,12 +35,11 @@ class factory
* Constructor
*
- * @param objec $container Container object
- * @param \phpbb\config\config $config Config object
+ * @param ContainerInterface $container Container object
+ * @param \phpbb\config\config $config Config object
* @param \phpbb\db\driver\driver_interface $db Database connection